@@ -6,8 +6,14 @@ __author__ = "Christian Staudt"
 # local imports
 
 # external imports
-import scipy.sparse
-import numpy as np
+try:
+	import scipy.sparse
+except ImportError:
+	print("module 'scipy' not available -- some functionality will be restricted")
+try:
+	import numpy as np
+except ImportError:
+	print("module 'numpy' not available -- some functionality will be restricted")
 
 
 
@@ -16,23 +22,28 @@ def column(matrix, i):
 	return [row[i] for row in matrix]
 
 
-def adjacencyMatrix(G):
+def adjacencyMatrix(G, matrixType="sparse"):
 	""" Get the adjacency matrix of the graph `G`.
 
 	Parameters
 	----------
 	G : Graph
 		The graph.
+	matrixType : string
+		represent"sparse" or "dense"
 
 	Returns
 	-------
 	:py:class:`scipy.sparse.csr_matrix`
 		The adjacency matrix of the graph.
 	"""
-	#if G.isDirected():
-	#	raise NotImplementedError("TODO: implement for directed graphs")
-	n = G.numberOfNodes()
-	A = scipy.sparse.lil_matrix((n,n))
+	n = G.upperNodeIdBound()
+	if matrixType is "sparse":
+		A = scipy.sparse.lil_matrix((n,n))
+	elif matrixType is "dense":
+		A = np.zeros(shape=(n,n))
+	else:
+		raise InputError("unknown matrix type: '{0}'".format(matrixType))
 	# TODO: replace .edges() with efficient iterations
 	if G.isWeighted():
 		if G.isDirected():
@@ -51,7 +62,8 @@ def adjacencyMatrix(G):
 				A[u, v] = 1
 				A[v, u] = 1
 	G.forEdges(processEdge)
-	A = A.tocsr()  # convert to CSR for more efficient arithmetic operations
+	if matrixType is "sparse":
+		A = A.tocsr()  # convert to CSR for more efficient arithmetic operations
 	return A
 
 def laplacianMatrix(G):
