@@ -6,6 +6,8 @@
  */
 
 #include "NumericTools.h"
+#include <cmath>
+#include <algorithm>
 
 namespace Aux {
 
@@ -23,6 +25,10 @@ bool ge(const double x, const double y, const double error) {
 	return (x >= (y - error));
 }
 
+bool logically_equal(double a, double b, double error_factor) {
+	return a==b || std::abs(a-b)<std::abs(std::min(a,b))*std::numeric_limits<double>::epsilon()*error_factor;
+}
+
 } /* namespace NumericTools */
 
 } /* namespace NetworKit */
