@@ -11,9 +11,9 @@
 
 namespace NetworKit {
 
-Dijkstra::Dijkstra(const Graph& G, node source, bool storePaths, bool storeNodesSortedByDistance, node target) : SSSP(G, source, storePaths, storeNodesSortedByDistance, target) {
-
-}
+Dijkstra::Dijkstra(const Graph &G, node source, bool storePaths,
+									 bool storeNodesSortedByDistance, node target)
+		: SSSP(G, source, storePaths, storeNodesSortedByDistance, target) {}
 
 void Dijkstra::run() {
 
@@ -34,12 +34,11 @@ void Dijkstra::run() {
 		std::vector<node> empty;
 		std::swap(nodesSortedByDistance, empty);
 	}
-	distances[source] = 0;
+
 	// priority queue with distance-node pairs
 	distances[source] = 0;
 	Aux::PrioQueue<edgeweight, node> pq(distances);
 
-
 	auto relax([&](node u, node v, edgeweight w) {
 		if (distances[v] > distances[u] + w) {
 			distances[v] = distances[u] + w;
@@ -52,8 +51,9 @@ void Dijkstra::run() {
 			pq.changeKey(distances[v], v);
 			TRACE("pq size: ", pq.size());
 		} else if (storePaths && (distances[v] == distances[u] + w)) {
-			previous[v].push_back(u); 	// additional predecessor
-			npaths[v] += npaths[u]; 	// all the shortest paths to u are also shortest paths to v now
+			previous[v].push_back(u); // additional predecessor
+			npaths[v] += npaths[u];   // all the shortest paths to u are
+																// also shortest paths to v now
 		}
 	});
 
@@ -62,9 +62,10 @@ void Dijkstra::run() {
 	while (pq.size() > 0) {
 		TRACE("pq size: ", pq.size());
 		node current = pq.extractMin().second;
-		TRACE("current node in Dijkstra: " , current);
+		TRACE("current node in Dijkstra: ", current);
 		TRACE("pq size: ", pq.size());
-		if (breakWhenFound && target == current) {
+		if ((breakWhenFound && target == current) ||
+				distances[current] == infDist) {
 			break;
 		}
 
@@ -74,8 +75,6 @@ void Dijkstra::run() {
 
 		G.forEdgesOf(current, relax);
 	}
-
 }
 
-
 } /* namespace NetworKit */
