@@ -22,11 +22,15 @@ public:
 
 	virtual void onNodeRemoval(node u) = 0;
 
+	virtual void onNodeRestoration(node u) = 0;
+
 	virtual void onEdgeAddition(node u, node v, edgeweight w = 1.0) = 0;
 
 	virtual void onEdgeRemoval(node u, node v, edgeweight w = 1.0) = 0;
 
 	virtual void onWeightUpdate(node u, node v, edgeweight wOld, edgeweight wNew) = 0;
+	
+	virtual void onWeightIncrement(node u, node v, edgeweight wOld, edgeweight delta) = 0;
 
 	virtual void onTimeStep() = 0;
 };
