@@ -40,12 +40,16 @@ public:
 
 	void removeNode(node u);
 
+	void restoreNode(node u);
+
 	void addEdge(node u, node v, edgeweight weight = defaultEdgeWeight);
 
 	void removeEdge(node u, node v);
 
 	void setWeight(node u, node v, edgeweight w);
 
+	void incrementWeight(node u, node v, edgeweight delta);
+
 	void timeStep();
 };
 
