@@ -40,9 +40,7 @@ DynamicHyperbolicGenerator::DynamicHyperbolicGenerator(std::vector<double> &angl
 
 	assert(radii.size() == nodeCount);
 	this->R = R;
-	for (double r : radii) {
-		assert(r < R);
-	}
+	assert(*std::max_element(radii.begin(), radii.end()) < R);
 
 	this->moveEachStep = moveEachStep;
 	this->moveDistance = moveDistance;
@@ -292,7 +290,11 @@ void DynamicHyperbolicGenerator::getEventsFromNodeMovement(vector<GraphEvent> &r
 			#pragma omp critical
 			{
 				bool removed = quad.removeContent(toWiggle[j], oldphi, oldr);
+#ifndef NDEBUG
 				assert(removed);
+#else
+				((void)(removed));
+#endif
 				quad.addContent(toWiggle[j], angles[toWiggle[j]], radii[toWiggle[j]]);
 			}
 		}
