@@ -34,7 +34,6 @@ private:
 	Point2D<double> a,b,c,d;
 	unsigned capacity;
 	static const unsigned coarsenLimit = 4;
-	static const long unsigned sanityNodeLimit = 10E15; //just assuming, for debug purposes, that this algorithm never runs on machines with more than 4 Petabyte RAM
 	count subTreeSize;
 	std::vector<T> content;
 	std::vector<Point2D<double> > positions;
@@ -149,7 +148,6 @@ public:
 	 * @param R radial coordinate of point, between 0 and 1.
 	 */
 	void addContent(T input, double angle, double R) {
-		assert(input < sanityNodeLimit);
 		assert(this->responsible(angle, R));
 		if (lowerBoundR > R) lowerBoundR = R;
 		if (isLeaf) {
@@ -549,8 +547,6 @@ public:
 				const double deltaY = positions[i].getY() - queryY;
 				if (deltaX*deltaX + deltaY*deltaY < rsq) {
 					result.push_back(content[i]);
-					if (content[i] >= sanityNodeLimit) DEBUG("Quadnode content ", content[i], " found, suspiciously high!");
-					assert(content[i] < sanityNodeLimit);
 				}
 			}
 		}	else {
@@ -568,7 +564,11 @@ public:
 		auto distancePair = hyperbolicDistances(phi_q, r_q);
 		double probUB = prob(distancePair.first);
 		double probLB = prob(distancePair.second);
+#ifndef NDEBUG
 		assert(probLB <= probUB);
+#else
+        ((void)(probLB));
+#endif
 		if (probUB > 0.5) probUB = 1;//if we are going to take every second element anyway, no use in calculating expensive jumps
 		if (probUB == 0) return 0;
 		//TODO: return whole if probLB == 1
@@ -749,7 +749,7 @@ public:
 	index indexSubtree(index nextID) {
 		index result = nextID;
 		assert(children.size() == 4 || children.size() == 0);
-		for (int i = 0; i < children.size(); i++) {
+		for (index i = 0; i < children.size(); i++) {
 			result = children[i].indexSubtree(result);
 		}
 		this->ID = result;
@@ -757,15 +757,14 @@ public:
 	}
 
 	index getCellID(double phi, double r) const {
-		if (!responsible(phi, r)) return -1;
+		if (!responsible(phi, r)) return NetworKit::none;
 		if (isLeaf) return getID();
 		else {
-			for (int i = 0; i < 4; i++) {
+			for (index i = 0; i < children.size(); i++) {
 				index childresult = children[i].getCellID(phi, r);
-				if (childresult >= 0) return childresult;
+				if (childresult != NetworKit::none) return childresult;
 			}
-			assert(false); //if responsible
-			return -1;
+			throw std::runtime_error("No responsible child node found even though this node is responsible.");
 		}
 	}
 
