@@ -27,7 +27,7 @@ public:
 	 * @note $$c(G) := \frac{1}{n} \sum_{u \in V} c(u)$$
 	 * where $c(u) := \frac{2 \cdot |E(N(u))| }{\deg(u) \cdot ( \deg(u) - 1)}$
 	 */
-	static double avgLocal(Graph& G);
+	static double avgLocal(Graph& G, bool turbo = false);
 	static double sequentialAvgLocal(const Graph &G);
   	static double approxAvgLocal(Graph& G, const count trials);
 
