@@ -72,6 +72,9 @@ namespace std {
 
 namespace NetworKit {
 
+// forward declaration to randomization/CurveballImpl.h
+namespace CurveballDetails {struct CurveballMaterialization;}
+
 /**
  * @ingroup graph
  * A graph (with optional weights) and parallel iterator methods.
@@ -80,6 +83,7 @@ class Graph final {
 
 	friend class ParallelPartitionCoarsening;
 	friend class GraphBuilder;
+	friend class CurveballDetails::CurveballMaterialization;
 
 private:
 	// graph attributes
