@@ -10,7 +10,7 @@
 
 namespace NetworKit {
 
-void SNAPGraphWriter::write(Graph& G, const std::string& path) {
+void SNAPGraphWriter::write(const Graph& G, const std::string& path) {
     std::ofstream file(path);
     Aux::enforceOpened(file);
 
