@@ -24,10 +24,13 @@ namespace NetworKit {
 class LocalMaxMatcher: public NetworKit::Matcher {
 public:
 
-	LocalMaxMatcher(Graph& G);
+	LocalMaxMatcher(const Graph& G);
 
 
-	virtual Matching run();
+	virtual void run();
+
+protected:
+
 };
 
 } /* namespace NetworKit */
